@@ -1,4 +1,3 @@
-// $Id: ss_csia.cpp$
 /*
      This library is free software; you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
@@ -16,11 +15,6 @@
      Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
      Boston, MA 02110-1301 USA
 */
-// =================================================================
-//
-//    29.04.04   <--  Date of Last Modification.
-//                   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-// -----------------------------------------------------------------
 //
 //  **** Module  :  ssm_csia  <implementation>
 //       ~~~~~~~~~
@@ -391,9 +385,14 @@ PCSSGraph  CSSGraphMatch::GetGraph2()  {
 
 void  CSSGraphMatch::MatchGraphs ( PCSSGraph Gh1, PCSSGraph Gh2,
                                    int minMatch )  {
-realtype s1,s2;
 int      i,j;
 
+  nMatches = 0;
+  maxCollectedMatch = 0;
+  maxRecursionLevel = 0;
+
+  if ((!Gh1) || (!Gh2))  return;
+
   if (Gh1->nVertices<=Gh2->nVertices)  {
     G1   = Gh1; 
     G2   = Gh2;
@@ -412,10 +411,6 @@ int      i,j;
   c1 = G1->graph;     // c[i][j] is the ordinal number of edge connecting
   c2 = G2->graph;     // vertices i and j; c[i][i]==-1.
 
-  nMatches = 0;
-  maxCollectedMatch = 0;
-  maxRecursionLevel = 0;
-
   if (n==1)  {
     MatchSingleVertex();
     if (swap)  {
