@@ -124,7 +124,7 @@ int  SelectDomain ( PCMMDBManager MMDB, int & selHnd, pstr select,
 int rc;
 
   selHnd = MMDB->NewSelection();
-  rc = MMDB->SelectDomain ( selHnd,select,selType,SKEY_NEW,1 );
+  rc = MMDB->SelectDomain ( selHnd,(cpstr)select,selType,SKEY_NEW,1 );
   if ((!rc) && (selType==STYPE_ATOM))  {
     // only C-alphas are needed
     MMDB->Select ( selHnd,selType,1,"*",ANY_RES,"*",ANY_RES,"*",
@@ -374,7 +374,8 @@ int        rc,nresidues,i,j,k,vtype;
     if (i<nresidues)  {
       j = i;
       while ((i<nresidues) && (res[i]->SSE==res[j]->SSE) &&
-             (!strcmp(res[i]->GetChainID(),res[j]->GetChainID())))  i++;
+             (!strcmp(res[i]->GetChainID(),res[j]->GetChainID())))
+        i++;
       if (res[j]->SSE==SSE_Strand)  vtype = V_STRAND;
                               else  vtype = V_HELIX;
       k++;
@@ -744,7 +745,7 @@ int  stype,selHnd1;
 
 
 void  CSSGraph::_leaveVertices ( PCMMDBManager M, int selHnd1 )  {
-int  selHnd2, i,j,n;
+int  selHnd2, i,n;
 
   selHnd2 = M->NewSelection();
 
