@@ -83,6 +83,7 @@ void CSSMAlign::InitSSMAlign()  {
   
   cnCheck     = CSSC_Flexible;
   rmsd        = 0.0;  // core rmsd achieved
+  Qscore      = 0.0;  // core Q achieved
   nres1       = 0;    // number of residues in query  structure
   nres2       = 0;    // number of residues in target structure
   nsel1       = 0;    // number of residues in query  selection
@@ -234,22 +235,22 @@ int        i,nMatches,nm;
   U.GetMatches ( Match,nMatches );
   if (nMatches<=0)  return SSM_noHits;
 
-  Q = -0.5;
+  Qscore = -0.5;
   for (i=0;i<nMatches;i++)
     if (Match[i])  {
       Match[i]->GetMatch ( F1,F2,nm );
       Superpose.SuperposeCalphas ( G1,G2,F1,F2,nm,M1,M2,
                                    selHnd1,selHnd2 );
       Q1 = Superpose.GetCalphaQ();
-      if ((Q1>0.0) && (Q1>Q))  {
-        Q = Q1;
+      if ((Q1>0.0) && (Q1>Qscore))  {
+        Qscore = Q1;
         Superpose.GetSuperposition ( Ca1,dist1,nres1,Ca2,nres2,TMatrix,
                                      rmsd,nalgn,ngaps,seqIdentity,
                                      nmd,ncombs );
       }
     }
 
-  if (Q>0.0)  {
+  if (Qscore>0.0)  {
     MakeSelections ( M1,selHnd1, M2,selHnd2 );
     return SSM_Ok;
   }
@@ -633,6 +634,14 @@ void CXAlign::makeRow ( PCAtom A1, int sseType1,
                         PCAtom A2, int sseType2,
                         realtype dist, int rowNo,
                         int icol, Boolean aligned )  {
+UNUSED_ARGUMENT(A1);
+UNUSED_ARGUMENT(sseType1);
+UNUSED_ARGUMENT(A2);
+UNUSED_ARGUMENT(sseType2);
+UNUSED_ARGUMENT(dist);
+UNUSED_ARGUMENT(rowNo);
+UNUSED_ARGUMENT(icol);
+UNUSED_ARGUMENT(aligned);
 }
 
 
