@@ -1434,7 +1434,7 @@ realtype thr2,d,d2;
 int      i, k1,k2,n1,n2,sw;
 Boolean  B1,B2;
  
- d = 0.0;
+  d = d2 = 0.0;
 
   thr2 = thresh*thresh;
   i    = 0;
@@ -1653,6 +1653,7 @@ int  i,k,m;
 
 realtype CSuperpose::CalcNCombs ( PCSSGraph G, PSSSEDesc SSED,
                                   int nSSEs, PSSpAtom  a, int nres ) {
+UNUSED_ARGUMENT(nres);
 ivector  F;
 realtype nc;
 int      i,j,k,n;
@@ -2134,8 +2135,8 @@ Boolean      Done;
     for (i=0;i<nSSEs2;i++)  SSED2[i].m = -1;
 
     //   1.3 Correspond atoms of matched SSEs first
-    for (i=1;i<=FFlen;i++)  {
-      CalcDistance ( FF1[i],FF2[i],D );
+    for (i=1;i<=copyFlen;i++)  {
+      CalcDistance ( copyF1[i],copyF2[i],D );
       AlignSSEs    ( D,UNMAP_NO );
     }
 
@@ -2412,9 +2413,9 @@ int  selHnd1,selHnd2;
       (!F1) || (!F2) || (mlen<=0) ||
       (!M1) || (!M2))  return SPOSE_BadData;
 
-  FF1   = F1;
-  FF2   = F2;
-  FFlen = mlen;
+  copyF1   = F1;
+  copyF2   = F2;
+  copyFlen = mlen;
   MMDB1 = M1;
   MMDB2 = M2;
 
@@ -2543,9 +2544,9 @@ int  i,j, rc;
       (!F1) || (!F2) || (mlen<=0))
     return SPOSE_BadData;
 
-  FF1   = F1;
-  FF2   = F2;
-  FFlen = mlen;
+  copyF1   = F1;
+  copyF2   = F2;
+  copyFlen = mlen;
   MMDB1 = SD1->M;
   MMDB2 = SD2->M;
 
@@ -2616,8 +2617,8 @@ void  CSuperpose::_superpose ( PCSSGraph G1, PCSSGraph G2,
 mat44 TMx0;
 int   i,j,i1,i2,AD_alloc;
 
-  IdentifyUnmatchedSSEs ( FH1,nFH1,FS1,nFS1,FF1,FFlen,G1 );
-  IdentifyUnmatchedSSEs ( FH2,nFH2,FS2,nFS2,FF2,FFlen,G2 );
+  IdentifyUnmatchedSSEs ( FH1,nFH1,FS1,nFS1,copyF1,copyFlen,G1 );
+  IdentifyUnmatchedSSEs ( FH2,nFH2,FS2,nFS2,copyF2,copyFlen,G2 );
 
   //  3. Allocate memory for corresponding atoms and shortest contacts
 
@@ -2653,11 +2654,11 @@ int   i,j,i1,i2,AD_alloc;
 
   //  4. Superpose secondary structures; TMx will be the initial guess
 
-  if (FFlen==1)  {
-    FirstGuess ( FF1,FF2,FFlen );
-    ChooseFirstRotation ( FF1[1],FF2[1] );
+  if (copyFlen==1)  {
+    FirstGuess ( copyF1,copyF2,copyFlen );
+    ChooseFirstRotation ( copyF1[1],copyF2[1] );
   } else
-    SuperposeSSGraphs ( G1,FF1,G2,FF2,FFlen );
+    SuperposeSSGraphs ( G1,copyF1,G2,copyF2,copyFlen );
   for (i=0;i<4;i++)
     for (j=0;j<4;j++)  {
       TMx0[i][j] = TMatrix[i][j];
@@ -2713,7 +2714,7 @@ int   i,j,i1,i2,AD_alloc;
 
   if (SDist)  {
     for (i=0;i<SDistAlloc;i++)
-      if (SDist[i])  delete SDist[i];
+      if (SDist[i])  delete[] SDist[i];
     delete[] SDist;
     SDist = NULL;
   }
