@@ -132,6 +132,8 @@ struct SSuperposeData  {
 #define  UNMAP_YES  (-2)
 #define  UNMAP_NO   (-1)
 
+#undef FF1 // sys/ioctl_compat.h, sys/termios.h under Mac OS (e.g. 10.6)
+
 DefineClass(CSuperpose)
 
 class CSuperpose  {
@@ -225,8 +227,8 @@ class CSuperpose  {
     rmatrix   A,U,V, AD;
     rvector   W,RV1;
 
-    ivector   FF1,FF2;  // copy pointers to input F1,F2
-    int       FFlen;    // length of FF1,FF2
+    ivector   copyF1,copyF2;   // copy pointers to input F1,F2
+    int       copyFlen;        // length of FF1,FF2
     rvector   cax0,cay0,caz0;  // working arrays
     PSSortDistData sdata;
 
